@@ -192,7 +192,7 @@ erc20_approve_abi = """
 """
 
 erc20_transfer_abi = """
-【{
+[{
   "constant": false,
   "inputs": [
     {
@@ -214,7 +214,7 @@ erc20_transfer_abi = """
   "payable": false,
   "stateMutability": "nonpayable",
   "type": "function"
-}】
+}]
 """ 
 
 def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token = "usdc", **kwargs):
@@ -390,7 +390,7 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
       if active_chain.lower() != chain.lower():
           params = {
             "func": "wallet_switchEthereumChain",
-            "chainId": "ETH"
+            "chainId": chain_id_mapping[chain.lower()]
           }
           action_data = ActionData(func='', group='', params=params)
           action = Action(msg=None, type='setting', data=action_data.__dict__)
@@ -440,7 +440,6 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
             'chainId': chain_id_mapping[chain.lower()],
             'contract': token,
             'func': 'transfer',
-            'token': token,
             'abi': erc20_transfer_abi
           }
           action_data = ActionData(func='transfer', group='transfer', params=params)
